# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/slim/slim/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/slim/slim/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Slim\\Slim\\": "packages/slim/slim/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Slim\Slim\Providers\SlimServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Slim'  => Slim\Slim\Facades\Slim::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Slim\\SlimTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Slim\Slim\Providers\SlimServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Slim\Slim\Providers\SlimServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Slim\Slim\Providers\SlimServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/slim/{modulename}

**User**

    http://path-to-route-folder/user/slim/{modulename}

**Public**

    http://path-to-route-folder/slims


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/slim/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/slim/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/slim/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/slim/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/slim/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/slim/{modulename}/{slug}
    METHOD: GET